# notemgmt

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)  
A command line tool to create and manage my latex study notes

## Features
* Create notes for lectures of current course using predefined latex templates

## Getting Started

### Supported OS
Ubuntu

### Prerequisites

```
  1. Python3
  2. pip3
```

### Installation

1. **Install the package**  
    * **Using pip**  
    `sudo pip3 install notemgmt`  

## Authors

* **Vinitra Muralikrishnan** - [VinitraMk](https://github.com/VinitraMk)

## License

This project is licensed under the GNU License - see the [LICENSE](LICENSE) file for details
